@@ -51,12 +51,8 @@ def objectify_notion_blocks(token_v2, pageId):
         ):
             setattr(jsonPage, "title", content.title)
         elif content.type == "image":
-            # TODO: Store image locally
-            # imagePath = utils.handleNotionImageSource(idx, content.source)
-            # setattr(jsonPage, 'imagePath', imagePath)
-            setattr(jsonPage, "imagePath", content.source)
+            setattr(jsonPage, "source", content.source)
 
-        jsonStr = jsonPage.toJSON()
-        results.append(jsonStr)
+        results.append(jsonPage)
 
     return results
